@@ -130,10 +130,10 @@ void SDSummaryWidget::configUpdated()
 {
     KConfig config(QStringLiteral("kcmsdsummaryrc"));
 
-    KConfigGroup group = config.group("Days");
+    KConfigGroup group = config.group(QStringLiteral("Days"));
     mDaysAhead = group.readEntry("DaysToShow", 7);
 
-    group = config.group("Show");
+    group = config.group(QStringLiteral("Show"));
     mShowBirthdaysFromKAB = group.readEntry("BirthdaysFromContacts", true);
     mShowBirthdaysFromCal = group.readEntry("BirthdaysFromCalendar", true);
 
@@ -144,7 +144,7 @@ void SDSummaryWidget::configUpdated()
 
     mShowSpecialsFromCal = group.readEntry("SpecialsFromCalendar", true);
 
-    group = config.group("Groupware");
+    group = config.group(QStringLiteral("Groupware"));
     mShowMineOnly = group.readEntry("ShowMineOnly", false);
 
     updateView();
@@ -153,7 +153,7 @@ void SDSummaryWidget::configUpdated()
 bool SDSummaryWidget::initHolidays()
 {
     KConfig _hconfig(QStringLiteral("korganizerrc"));
-    KConfigGroup hconfig(&_hconfig, "Time & Date");
+    KConfigGroup hconfig(&_hconfig, QStringLiteral("Time & Date"));
     QString location = hconfig.readEntry("Holidays");
     if (!location.isEmpty()) {
         delete mHolidays;
@@ -644,7 +644,7 @@ void SDSummaryWidget::viewContact(const QString &url)
         return;
     }
 
-    QPointer<ContactEditor::ContactViewerDialog> dlg = new ContactEditor::ContactViewerDialog(this);
+    QPointer<Akonadi::ContactViewerDialog> dlg = new Akonadi::ContactViewerDialog(this);
     dlg->setContact(item);
     dlg->exec();
     delete dlg;
@@ -707,3 +707,5 @@ void SDSummaryWidget::dateDiff(const QDate &date, int &days, int &years) const
 }
 
 #include "sdsummarywidget.moc"
+
+#include "moc_sdsummarywidget.cpp"
